@@ -76,7 +76,7 @@ our %Declination=(
     "-15:52",
     "-15:34",
     "-15:15",
-    "_14:56",
+    "-14:56",
     "-14:37",
 
     "-14:18",
